"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCommitRecord = exports.serviceClient = void 0;
const axios_1 = __importDefault(require("axios"));
const logger_1 = require("./logger");
const consts_1 = require("./consts");
exports.serviceClient = axios_1.default.create({
    baseURL: `${consts_1.serviceUrl}/v1`,
    timeout: 7000,
    headers: {
        'x-api-client-name': 'bundlemon-cli',
        'x-api-client-version': consts_1.version,
    },
});
function logError(err, prefix) {
    const logger = logger_1.createLogger(prefix);
    if (err.isAxiosError) {
        const axiosError = err;
        if (axiosError.response) {
            switch (axiosError.response.status) {
                case 400: {
                    logger.error('validation failed', JSON.stringify(axiosError.response.data, null, 2));
                    break;
                }
                case 403: {
                    // TODO: add documentation about this kind of error
                    logger.error('bad project credentials', JSON.stringify(axiosError.response.data));
                    break;
                }
                default: {
                    logger.error(`server returned ${axiosError.response.status}`, axiosError.response.data);
                }
            }
        }
        else if (axiosError.request) {
            // client never received a response, or request never left
            logger.error(`Cant reach server (${consts_1.serviceUrl}) code "${axiosError.code}"`);
        }
        else {
            logger.error('Unknown error', err);
        }
    }
    else {
        logger.error('Unknown error', err);
    }
}
function createCommitRecord(projectId, payload, authHeaders) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const res = yield exports.serviceClient.post(`/projects/${projectId}/commit-records`, payload, {
                headers: authHeaders,
            });
            return res.data;
        }
        catch (err) {
            logError(err, 'create commit record');
        }
        return undefined;
    });
}
exports.createCommitRecord = createCommitRecord;
