"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const yup = __importStar(require("yup"));
const ci_1 = require("../../utils/ci");
const logger_1 = require("../../../common/logger");
const validationUtils_1 = require("../../utils/validationUtils");
const service_1 = require("../../../common/service");
const NAME = 'github';
const logger = logger_1.createLogger(`${NAME} output`);
function validateOptions(options) {
    const schema = yup
        .object()
        .required()
        .shape({
        checkRun: yup.boolean().optional().default(false),
        commitStatus: yup.boolean().optional().default(true),
        prComment: yup.boolean().optional().default(true),
    });
    return validationUtils_1.validateYup(schema, options, `${NAME} output`);
}
function logGithubError(err, body) {
    var _a, _b, _c;
    if (err.isAxiosError) {
        const axiosError = err;
        logger.error(`Github returned ${(_a = axiosError === null || axiosError === void 0 ? void 0 : axiosError.response) === null || _a === void 0 ? void 0 : _a.status}`);
        try {
            logger.error(JSON.stringify((_b = axiosError === null || axiosError === void 0 ? void 0 : axiosError.response) === null || _b === void 0 ? void 0 : _b.data, null, 2));
        }
        catch (_d) {
            logger.error((_c = axiosError === null || axiosError === void 0 ? void 0 : axiosError.response) === null || _c === void 0 ? void 0 : _c.data);
        }
    }
    else {
        logger.error('Unknown error', err);
    }
    try {
        logger.debug('request body:');
        logger.debug(JSON.stringify(body, null, 2));
    }
    catch (_e) {
        logger.debug(body);
    }
}
const output = {
    name: NAME,
    create: ({ options, config }) => {
        const normalizedOptions = validateOptions(options);
        if (!normalizedOptions) {
            throw new Error(`validation error in output "${NAME}" options`);
        }
        if (!config.remote) {
            logger.warn('remote flag is OFF, ignore output');
            return undefined;
        }
        if (!ci_1.owner || !ci_1.repo) {
            throw new Error('Missing "CI_REPO_OWNER" & "CI_REPO_NAME" env vars');
        }
        return {
            generate: (report) => __awaiter(void 0, void 0, void 0, function* () {
                const { projectId, getAuthHeaders, gitVars: { commitSha, prNumber }, } = config;
                logger.debug(`Owner: "${ci_1.owner}" Repo: "${ci_1.repo}" sha: "${commitSha}" PR: "${prNumber}"`);
                const payload = {
                    git: { owner: ci_1.owner, repo: ci_1.repo, commitSha, prNumber },
                    report,
                    output: normalizedOptions,
                };
                try {
                    const { data: response } = yield service_1.serviceClient.post(`projects/${projectId}/outputs/github`, payload, {
                        headers: getAuthHeaders(),
                    });
                    let didFail = false;
                    for (const [type, result] of Object.entries(response)) {
                        let logFunc = logger.info;
                        if (result.result === 'failure') {
                            logFunc = logger.error;
                            didFail = true;
                        }
                        logFunc(`Create GitHub "${type}": ${result.result} - ${result.message}`);
                    }
                    if (didFail) {
                        throw new Error('One or more GitHub outputs failed');
                    }
                }
                catch (err) {
                    logGithubError(err, payload);
                    throw err;
                }
            }),
        };
    },
};
exports.default = output;
